diff options
| author | Claudius "keldu" Holeksa <mail@keldu.de> | 2026-08-05 17:13:19 +0200 |
|---|---|---|
| committer | Claudius "keldu" Holeksa <mail@keldu.de> | 2026-08-05 17:13:19 +0200 |
| commit | a0767a86817055744230239284441fdbb024fab5 (patch) | |
| tree | ea958f763e49f4a3a861c4436756694cd983bc97 /examples/moving_poiseulle_particles_2d_fplbm_gpu/sim.cpp | |
| parent | 80deace4d4b2c93945feeec42a8269f3ba2443d2 (diff) | |
| download | libs-lbm-a0767a86817055744230239284441fdbb024fab5.tar.gz | |
WOrking on psm 2way
Diffstat (limited to 'examples/moving_poiseulle_particles_2d_fplbm_gpu/sim.cpp')
| -rw-r--r-- | examples/moving_poiseulle_particles_2d_fplbm_gpu/sim.cpp | 4 |
1 files changed, 2 insertions, 2 deletions
diff --git a/examples/moving_poiseulle_particles_2d_fplbm_gpu/sim.cpp b/examples/moving_poiseulle_particles_2d_fplbm_gpu/sim.cpp index 09b2616..c82f632 100644 --- a/examples/moving_poiseulle_particles_2d_fplbm_gpu/sim.cpp +++ b/examples/moving_poiseulle_particles_2d_fplbm_gpu/sim.cpp @@ -185,7 +185,7 @@ saw::error_or<void> step( }).wait(); q.submit([&](acpp::sycl::handler& h){ - component<T,Desc,cmpt::FpLbmOneParticle,encode::Sycl<saw::encode::Native>> fplbm_one_part; + component<T,Desc,cmpt::FpLbmOneParticleImplicit,encode::Sycl<saw::encode::Native>> fplbm_one_part; h.parallel_for(acpp::sycl::range<1u>{particle_amount}, [=](acpp::sycl::id<1u> idx){ saw::data<sch::FixedArray<sch::UInt64,1u>> index; @@ -262,7 +262,7 @@ saw::error_or<void> lbm_main(int argc, char** argv){ } auto& lbm_dir = eo_lbm_dir.get_value(); - auto out_dir = lbm_dir / "moving_poiseulle_particles_2d_fplbm_gpu"; + auto out_dir = lbm_dir / "moving_poiseulle_particles_2d_fplbm_imp_gpu"; { std::error_code ec; |
